<?php
/**
 * Plugin Name: Add Custom Codes
 * Description: Light-weight plugin to add custom CSS, Javascript, Google Analytics, Meta verification tags and other code snippets to your Wordpress site. Go to <em>Appearance -> Custom Codes</em> after installing the plugin.
 * Version: 2.0
 * Author: Saifudheen Mak
 * Author URI: http://saifumak.com
 * License: GPL2
 * Text Domain: add-custom-codes
 */
 
 add_action( 'init', 'accodes_load_textdomain' );
function accodes_load_textdomain() {
  load_plugin_textdomain( 'add-custom-codes', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}

/*---------------------------------
styles and scripts for plugin page
-----------------------------------------*/
function accodes_styles_init() {

		wp_register_style( 'add-custom-codes', plugins_url( 'add-custom-codes/css/styles.css' ) );
		wp_enqueue_style( 'add-custom-codes' );
		
		wp_register_style( 'add-custom-codes1', plugins_url( 'add-custom-codes/css/codemirror.css' ) );
		wp_enqueue_style( 'add-custom-codes1' );
		
		wp_register_script( 'add-custom-codes2', plugins_url( 'add-custom-codes/js/codemirrornew.js' ) );
		wp_enqueue_script( 'add-custom-codes2' );	
		
		wp_register_script( 'add-custom-codes3', plugins_url( 'add-custom-codes/js/css.js' ) );
		wp_enqueue_script( 'add-custom-codes3' );	
		
		wp_register_script( 'add-custom-codes4', plugins_url( 'add-custom-codes/js/script.js' ) );
		wp_enqueue_script( 'add-custom-codes4' );
		
		wp_register_script( 'add-custom-codes5', plugins_url( 'add-custom-codes/js/addon/placeholder.js' ) );
		wp_enqueue_script( 'add-custom-codes5' );
		
	}
add_action( 'admin_init', 'accodes_styles_init' );

/*------------------------------
add menu icon
------------------------*/
add_action('admin_menu', 'accodes_menu');

function accodes_menu() {
	add_theme_page('Add Custom Codes', 'Custom Codes', 'administrator', 'add-custom-codes', 'accodes_settings_page');
}

function accodes_settings_page() {
 ?>


<div class="wrap">
<h2><?php _e( 'Custom Codes', 'add-custom-codes' ) ?></h2>
<div class="full_row">
<div class="accodes_cols">
<form method="post" action="options.php">
    <?php settings_fields( 'accodes-settings-group' ); ?>
    <?php do_settings_sections( 'accodes-settings-group' ); ?>
<p><strong><?php _e( 'Custom CSS', 'add-custom-codes' ) ?></strong><br/>
You can add custom css codes below. Do not include &lt;style&gt; and &lt;/style&gt; tags:</p>    
	<textarea class="codemirror" id="custom-css-codes-input" name="custom-css-codes-input"><?php echo esc_attr( get_option('custom-css-codes-input') ); ?></textarea>
	<?php submit_button(); ?>

    <p><strong><?php _e( 'Header Codes', 'add-custom-codes' ) ?></strong><br/>
Codes for &lt;head&gt; section of your website. Google Search Console Verification, Bing Verification and any other meta codes one at a line: </p>
      <textarea class="codemirror" id="custom-verification-codes-input" name="custom-header-codes-input"><?php echo esc_attr( get_option('custom-header-codes-input') ); ?></textarea>    
    <?php submit_button(); ?>
    
<p><strong><?php _e( 'Footer Codes', 'add-custom-codes' ) ?></strong><br/>
Codes to add before &lt;/body&gt; section of your website. Google Anayltics Tracking Code, Facebook Scripts, third party ad scripts etc. Be sure to include &lt;script&gt; and &lt;/script&gt; tags provided by the party: </p>
      <textarea class="codemirror" placeholder="" id="custom-analytics-codes-input" name="custom-footer-codes-input"><?php echo esc_attr( get_option('custom-footer-codes-input') ); ?></textarea>    
    <?php submit_button(); ?>

</form>
</div>
<div class="accodes_cols2">
	<div class="accodes_box">
		<h3>Happy with the plugin?</h3>
		<p>Please donate something to support the further development of this plugin and other new plugins that are on the way. You can choose how much to donate!</p>
		<center><a class="accodes_donate" href="https://www.paypal.me/MakTal" target="_blank">Donate</a></center>
	</div>
</div>

</div>
<?php
}

/*---------------------------
define items in settings page
-------------------------------*/
add_action( 'admin_init', 'accodes_settings' );

function accodes_settings() {
	register_setting( 'accodes-settings-group', 'custom-css-codes-input' );
	register_setting( 'accodes-settings-group', 'custom-footer-codes-input' );
	register_setting( 'accodes-settings-group', 'custom-header-codes-input' );
}




/*---------------------------------
output css
----------------*/
add_action( 'wp_head', 'accodes_css_output' );
function accodes_css_output() {
$options  = get_option( 'custom-css-codes-input' );
if($options!='')
{
echo PHP_EOL.'<!-- Snippet by Add Custom Codes -->'. PHP_EOL;
echo '<style type="text/css">';
echo ''. PHP_EOL;
 echo $options;
echo ''. PHP_EOL.'</style>'.PHP_EOL;
echo ''.PHP_EOL;
}
  
}

/*---------------------------------
output Footer Codes
----------------*/
add_action( 'wp_footer', 'accodes_footer_output' );
function accodes_footer_output() {
 $options  = get_option( 'custom-footer-codes-input' );
 if($options!="")
 {
echo PHP_EOL.'<!-- Snippet by Add Custom Codes -->'. PHP_EOL;
 echo $options;
echo ''.PHP_EOL;
echo ''.PHP_EOL;
 } 
}

/*---------------------------------
output Header Codes
----------------*/
add_action( 'wp_head', 'accodes_header_output' );
function accodes_header_output() {
$options  = get_option( 'custom-header-codes-input' );
if($options!='')
{
echo PHP_EOL.'<!-- Snippet by Add Custom Codes -->'. PHP_EOL;
 echo $options;
echo ''.PHP_EOL;
echo ''.PHP_EOL;
}
  
}


?>